package statistics

import (
	"context"
	"github.com/pkg/errors"
	"live-service/app/user_center/model"
	"live-service/app/user_center/rpc/internal/svc"
	"live-service/app/user_center/rpc/pb"

	"github.com/zeromicro/go-zero/core/logx"
)

type StatPvpDamageLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewStatPvpDamageLogic(ctx context.Context, svcCtx *svc.ServiceContext) *StatPvpDamageLogic {
	return &StatPvpDamageLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

//  statistics
func (l *StatPvpDamageLogic) StatPvpDamage(in *pb.StatPvPDamageReq) (*pb.Empty, error) {
	damage64 := int64(in.Damage)
	exists, _ := l.svcCtx.StatisticsPvpModel.Exists(l.ctx, in.Uid)
	if !exists {
		dbModel := &model.StatisticsPvp{
			UserId: in.Uid,
			Damage: damage64,
		}
		if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
			return nil, errors.Wrapf(err, ErrInsertErr, err)
		}
		return &pb.Empty{}, nil
	}
	// 原始记录存在，直接更新，提高效率
	if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, in.Uid, &model.UpdateRecordProps{Damage: &damage64}); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	// 承伤
	if in.TargetUid != nil {
		tUid := *in.TargetUid
		exists, _ = l.svcCtx.StatisticsPvpModel.Exists(l.ctx, tUid)
		if !exists {
			dbModel := &model.StatisticsPvp{
				UserId:   tUid,
				DeDamage: int64(in.Damage),
			}
			if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
				return nil, errors.Wrapf(err, ErrInsertErr, err)
			}
			return &pb.Empty{}, nil
		}
		// 原始记录存在，直接更新，提高效率
		if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, tUid, &model.UpdateRecordProps{DeDamage: &damage64}); err != nil {
			return nil, errors.Wrapf(err, ErrUpdateErr, err)
		}
	}

	return &pb.Empty{}, nil
}
