package statistics

import (
	"context"
	"github.com/pkg/errors"
	"live-service/app/user_center/model"

	"live-service/app/user_center/rpc/internal/svc"
	"live-service/app/user_center/rpc/pb"

	"github.com/zeromicro/go-zero/core/logx"
)

type StatPvpKillLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewStatPvpKillLogic(ctx context.Context, svcCtx *svc.ServiceContext) *StatPvpKillLogic {
	return &StatPvpKillLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *StatPvpKillLogic) StatPvpKill(in *pb.StatPvPKillReq) (*pb.Empty, error) {
	exists, _ := l.svcCtx.StatisticsPvpModel.Exists(l.ctx, in.Uid)
	if !exists {
		dbModel := &model.StatisticsPvp{
			UserId:          in.Uid,
			KillPlayerCount: 1,
		}
		if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
			return nil, errors.Wrapf(err, ErrInsertErr, err)
		}
		return &pb.Empty{}, nil
	}
	props := model.UpdateRecordProps{}
	if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, in.Uid, &props); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	// 被杀
	exists, _ = l.svcCtx.StatisticsPvpModel.Exists(l.ctx, in.TargetUid)
	if !exists {
		dbModel := &model.StatisticsPvp{
			UserId:          in.TargetUid,
			DeKillUnitCount: 1,
		}
		if in.IsGeneral {
			dbModel.DeGeneralCount = 1
		}
		if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
			return nil, errors.Wrapf(err, ErrInsertErr, err)
		}
		return &pb.Empty{}, nil
	}
	props = model.UpdateRecordProps{
		DeKillPlayer: true,
	}
	if in.IsGeneral {
		props.DeGeneral = true
	}
	if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, in.TargetUid, &props); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	return &pb.Empty{}, nil
}
