package statistics

import (
	"context"
	"github.com/pkg/errors"
	"live-service/app/user_center/model"

	"live-service/app/user_center/rpc/internal/svc"
	"live-service/app/user_center/rpc/pb"

	"github.com/zeromicro/go-zero/core/logx"
)

type StatPvpKillUnitLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewStatPvpKillUnitLogic(ctx context.Context, svcCtx *svc.ServiceContext) *StatPvpKillUnitLogic {
	return &StatPvpKillUnitLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *StatPvpKillUnitLogic) StatPvpKillUnit(in *pb.StatPvPKillUnitReq) (*pb.Empty, error) {
	exists, _ := l.svcCtx.StatisticsPvpModel.Exists(l.ctx, in.Uid)
	if !exists {
		dbModel := &model.StatisticsPvp{
			UserId:        in.Uid,
			KillUnitCount: 1,
		}
		if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
			return nil, errors.Wrapf(err, ErrInsertErr, err)
		}
		return &pb.Empty{}, nil
	}
	// 原始记录存在，直接更新，提高效率
	if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, in.Uid, &model.UpdateRecordProps{KillUnit: true}); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	// 被击杀
	if in.TargetUid != nil {
		tUid := *in.TargetUid
		exists, _ = l.svcCtx.StatisticsPvpModel.Exists(l.ctx, tUid)
		if !exists {
			dbModel := &model.StatisticsPvp{
				UserId:          tUid,
				DeKillUnitCount: 1,
			}
			if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
				return nil, errors.Wrapf(err, ErrInsertErr, err)
			}
			return &pb.Empty{}, nil
		}
		// 原始记录存在，直接更新，提高效率
		if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, tUid, &model.UpdateRecordProps{DeKillUnit: true}); err != nil {
			return nil, errors.Wrapf(err, ErrUpdateErr, err)
		}
	}

	return &pb.Empty{}, nil
}
